#include "SDL.h"
#include "gl.h"
#include "glu.h"

float xrf, yrf, zrf;
int fps=0;

void DrawGLScene();
Uint32 my_callbackfunc(Uint32 interval, void *param);
void* my_callback_param;

int main(){

 if ( SDL_Init(SDL_INIT_TIMER|SDL_INIT_VIDEO) < 0 ){ 
   printf("Unable to init SDL: %s\n", SDL_GetError()); 
   exit(1); 
 } 
 
 atexit(SDL_Quit); 

 SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
 SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 5);
 SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 6);
 SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 5); 
 
 if ( SDL_SetVideoMode(640,480,32,SDL_OPENGL) == NULL ){ 
   printf("Unable to set 640x480 video: %s\n", SDL_GetError()); 
   exit(1); 
 }


 glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
 glClearDepth(1.0);
 glDepthFunc(GL_LESS);
 glEnable(GL_DEPTH_TEST);
 glShadeModel(GL_SMOOTH);
 glMatrixMode(GL_PROJECTION);
 glLoadIdentity();
 gluPerspective(45.0f,640/480,0.1f,100.0f);
 glMatrixMode(GL_MODELVIEW);   
 
 SDL_TimerID my_timer_id = SDL_AddTimer(1000, my_callbackfunc, my_callback_param);
 
 int done=0; 
 while(done == 0){ 
   
   SDL_Event event; 
   
   while ( SDL_PollEvent(&event) ){ 
     if ( event.type == SDL_QUIT ){ 
      done = 1; 
     } 
     if ( event.type == SDL_KEYDOWN ){
       if ( event.key.keysym.sym == SDLK_ESCAPE ){ 
         done = 1; 
       } 
     } 
   } 
   
   DrawGLScene();
   glFlush();
   SDL_GL_SwapBuffers();
   fps++;
 }

 return 0;

}

void DrawGLScene(){

  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
  
  glLoadIdentity();
  glTranslatef(0.0f,0.0f,-7.0f);        //   
  
  glRotatef(xrf, 1.0f, 0.0f, 0.0f);        //    X, Y & Z
  glRotatef(yrf, 0.0f, 1.0f, 0.0f);        //    X, Y & Z
  glRotatef(zrf, 0.0f, 0.0f, 1.0f);        //    X, Y & Z
  
  glBegin(GL_QUADS);                      //  

    glColor3f(0.0f,1.0f,0.0f);              // 
    glVertex3f( 1.0f, 1.0f,-1.0f);          //    ()
    glVertex3f(-1.0f, 1.0f,-1.0f);          //  
    glVertex3f(-1.0f, 1.0f, 1.0f);          //  
    glVertex3f( 1.0f, 1.0f, 1.0f);          //  
    
    glColor3f(1.0f,0.5f,0.0f);              // 
    glVertex3f( 1.0f,-1.0f, 1.0f);          //    ()
    glVertex3f(-1.0f,-1.0f, 1.0f);          //  
    glVertex3f(-1.0f,-1.0f,-1.0f);          //  
    glVertex3f( 1.0f,-1.0f,-1.0f);          //  
    
    glColor3f(1.0f,0.0f,0.0f);              // 
    glVertex3f( 1.0f, 1.0f, 1.0f);          //    ()
    glVertex3f(-1.0f, 1.0f, 1.0f);          //  
    glVertex3f(-1.0f,-1.0f, 1.0f);          //  
    glVertex3f( 1.0f,-1.0f, 1.0f);          //  

    glColor3f(1.0f,1.0f,0.0f);              // 
    glVertex3f( 1.0f,-1.0f,-1.0f);          //    ()
    glVertex3f(-1.0f,-1.0f,-1.0f);          //  
    glVertex3f(-1.0f, 1.0f,-1.0f);          //  
    glVertex3f( 1.0f, 1.0f,-1.0f);          //  

    glColor3f(0.0f,0.0f,1.0f);              // 
    glVertex3f(-1.0f, 1.0f, 1.0f);          //    ()
    glVertex3f(-1.0f, 1.0f,-1.0f);          //  
    glVertex3f(-1.0f,-1.0f,-1.0f);          //  
    glVertex3f(-1.0f,-1.0f, 1.0f);          //  
    
    glColor3f(1.0f,0.0f,1.0f);              // 
    glVertex3f( 1.0f, 1.0f,-1.0f);          //    ()
    glVertex3f( 1.0f, 1.0f, 1.0f);          //  
    glVertex3f( 1.0f,-1.0f, 1.0f);          //  
    glVertex3f( 1.0f,-1.0f,-1.0f);          //  

  glEnd();                                //      
  
  xrf -= 0.15;
  yrf -= 0.2;
  zrf -= 0.25;
}

Uint32 my_callbackfunc(Uint32 interval, void *param){
 printf("FPS = %d\n", fps);
 fps=0;
 return interval;
}
