#include <stdio.h>
#include <stdlib.h>

#include "SDL.h"
#include "SDL_image.h"
#include "dga/dga_sdl.h"

SDL_Surface* ImageLoad(char *file);
int InitImages();
void DrawIMG(SDL_Surface *img, int x, int y);
void DrawIMG(SDL_Surface *img, int x, int y, int w, int h, int sx, int sy);
void DrawBG(void);
void DrawScene(void);
void ScrollBG();
Uint32 my_callbackfunc(Uint32 interval, void *param);


int video_flags = SDL_HWSURFACE|SDL_DOUBLEBUF;
void* my_callback_param;
int FPS;
SDL_Surface *screen, *back;
int ScrollSpeed = 5;
int ScrollWidth = 0;

//-----------------------------------------
int main(int argc, char *argv[]){ 
 
DGA_SetEnv();
 
 if ( SDL_Init(SDL_INIT_TIMER|SDL_INIT_VIDEO) < 0 ){ 
   printf("Unable to init SDL: %s\n", SDL_GetError()); 
   exit(1); 
 } 
 
 atexit(SDL_Quit); 

 SDL_WM_SetCaption("Side scroller","ex5");
 
 screen=SDL_SetVideoMode(800,600,32, video_flags);
 if ( screen == NULL ){ 
   printf("Unable to set 800x600 video: %s\n", SDL_GetError()); 
   exit(1); 
 }
 
 InitImages();
 DrawBG();
 
 SDL_TimerID my_timer_id = SDL_AddTimer(1000, my_callbackfunc, my_callback_param);
 int done=0; 
 SDL_Event event;
 
 while(done == 0){ 
 
   while ( SDL_PollEvent(&event) != 0 ){ 
     switch(event.type){
     case SDL_QUIT:
     	done=1; 
	break;

     case SDL_KEYDOWN:
       if ( event.key.keysym.sym == SDLK_ESCAPE ){ done = 1; }
       break;
     }
       
   }
   
   DrawScene();
 }
 
 SDL_RemoveTimer(my_timer_id);
 
 DGA_RestoreEnv(); 
 return 0;
  
}

//-----------------------------------------
SDL_Surface* ImageLoad(char *file){
  
  SDL_Surface *temp1, *temp2;
  temp1 = IMG_Load(file);
  if(temp1==NULL){
   printf("Can't load image file %s\n",file);
   return NULL;
  }
  temp2 = SDL_DisplayFormat(temp1);
  SDL_FreeSurface(temp1);
  
  return temp2;

}

//-----------------------------------------
int InitImages(){

 back = ImageLoad("data/bg.jpg");
 
 return 0;

}

//-----------------------------------------
void DrawIMG(SDL_Surface *img, int x, int y){

 SDL_Rect dest;
 dest.x = x;
 dest.y = y;

 SDL_BlitSurface(img, NULL, screen, &dest);

}

//-----------------------------------------
void DrawIMG(SDL_Surface *img, int x, int y, int w, int h, int sx, int sy){

 SDL_Rect dest;
 dest.x = x;
 dest.y = y;

 SDL_Rect src;
 src.x = sx;
 src.y = sy;
 src.w = w;
 src.h = h;
 
 SDL_BlitSurface(img, &src, screen, &dest);

}

/* ------------------------------------------- */
void DrawBG(){

 DrawIMG(back, 0, 0);
 SDL_Flip(screen);

}

//-----------------------------------------
void DrawScene(void){

  ScrollBG();

  SDL_Flip(screen);
  FPS++;
  
}

//-----------------------------------------
void ScrollBG(){

 DrawIMG(back, ScrollWidth, 0, back->w - ScrollWidth, back->h, 0, 0);
 DrawIMG(back, 0, 0, ScrollWidth, back->h, back->w - ScrollWidth, 0); 

 
 ScrollWidth += ScrollSpeed;
 if(ScrollWidth > 800)
 	ScrollWidth = 0;

}

//-----------------------------------------
Uint32 my_callbackfunc(Uint32 interval, void *param){

 printf("FPS: %d\n",FPS); 
 FPS=0;
 return interval;
}
