// -------------------------------------------------------------
// Title:	CSprite2 library
// Version:	0.80
// Description:	2D SDL animated sprites made easy.
//		Supporting animated sprites from single BMP.
// Dependences:	SDL library
// File:	csprite2.cxx
// License:	GNU Library General Public License 2 (LGPL2)
// Authors:	Evgeny Bronnikov <bbroth@pochta.ru>
// -------------------------------------------------------------

#include "csprite2.h"

//---------------------------------------------
int CSprite2::init(CSpriteBase2 *base, SDL_Surface *screen)
{
  mSpriteBase = base;
  if(mSpriteBase->mNumFrames>1) mAnimating=1;
    mBackreplacement = SDL_DisplayFormat(mSpriteBase->mAnim[0].image);
  mScreen = screen;
  return 0;
}

//---------------------------------------------
void CSprite2::clearBG()
{
  if(mDrawn==1)
  {
    SDL_Rect dest;
    dest.x = mOldX;
    dest.y = mOldY;
    dest.w = mSpriteBase->mW;
    dest.h = mSpriteBase->mH;
    SDL_BlitSurface(mBackreplacement, NULL, mScreen, &dest);
  }
}

//---------------------------------------------
void CSprite2::updateBG()
{
  SDL_Rect srcrect;
  srcrect.w = mSpriteBase->mW;
  srcrect.h = mSpriteBase->mH;
  srcrect.x = mX;
  srcrect.y = mY;
  mOldX=mX;
  mOldY=mY;
  SDL_BlitSurface(mScreen, &srcrect, mBackreplacement, NULL);
}

//---------------------------------------------
void CSprite2::draw()
{
  if(mAnimating == 1)
  {
    if(mLastupdate+mSpriteBase->mPause*mSpeed < SDL_GetTicks())
    {
      mFrame++;
      if(mFrame>mSpriteBase->mNumFrames-1) mFrame=0;
      mLastupdate = SDL_GetTicks();
    }
  }

  if(mDrawn==0) mDrawn=1;
  
  SDL_Rect dest;
  dest.x = mX; dest.y = mY;
  SDL_BlitSurface(mSpriteBase->mAnim[mFrame].image, NULL, mScreen, &dest);
}

//---------------------------------------------
void CSprite2::draw(int updating)
{
  draw();
  
  SDL_UpdateRect(mScreen,mX,mY,mSpriteBase->mW,mSpriteBase->mH);
}
