// -------------------------------------------------------------
// Title:	CSprite2 library
// Version:	0.80
// Description:	2D SDL animated sprites made easy.
//		Supporting animated sprites from single BMP.
// Dependences:	SDL library
// File:	csprite2.h
// License:	GNU Library General Public License 2 (LGPL2)
// Authors:	Evgeny Bronnikov <bbroth@pochta.ru>
// -------------------------------------------------------------


#ifndef __CSPRITE2_H__
#define __CSPRITE2_H__

#include "cspritebase2.h"
#include "SDL.h"

class CSprite2
{
  public:
  CSprite2(){}
  ~CSprite2(){}
  
// init class
  int init(CSpriteBase2 *base, SDL_Surface *screen);
  
// Blit sprite to screen surface. You must update screen manually.
  void draw();

// Blit sprite and update rectangle (a part of screen).
  void draw(int updating);

// Clear sprite rectangle with background.
  void clearBG();
  
// Update erasing data (background rectangle).
  void updateBG();


// Set and get frame of animation.
  void setFrame(int nr) { mFrame = nr; }
  int getFrame() { return mFrame; }
  
// Set and get animation speed.
  void setSpeed(float nr) { mSpeed = nr; }
  float getSpeed() { return mSpeed; }
  
// Playback control tools.
  void toggleAnim() { mAnimating = !mAnimating; }
  void startAnim() { mAnimating = 1; }
  void stopAnim() {mAnimating = 0; }
  void rewind() {mFrame = 0; }
  
// ;)
  int getWidth() { return mSpriteBase->mW; }
  int getHeight() { return mSpriteBase->mH; }
  
  int getX() { return mX; }
  int getY() { return mY; }
  
  void xadd(int nr) { mX+=nr; }
  void yadd(int nr) { mY+=nr; }  
  void xset(int nr) { mX=nr; }
  void yset(int nr) { mY=nr; }
  void set(int xx, int yy) { mX=xx; mY=yy; } // set both coordinates
  
  private:
  
// Some internal stuff

  int mFrame;
  int mX, mY, mOldX, mOldY;
  int mAnimating;
  int mDrawn;
  float mSpeed;
  long mLastupdate;
  CSpriteBase2 *mSpriteBase;
  SDL_Surface *mBackreplacement;
  SDL_Surface *mScreen;
};


#endif //__CSPRITE2_H__
