// -------------------------------------------------------------
// Title:	CSprite2 library
// Version:	0.80
// Description:	2D SDL animated sprites made easy.
//		Supporting animated sprites from single BMP.
// Dependences:	SDL library
// File:	cspritebase2.cxx
// License:	GNU Library General Public License 2 (LGPL2)
// Authors:	Evgeny Bronnikov <bbroth@pochta.ru>
// -------------------------------------------------------------

#include <stdio.h>
#include "cspritebase2.h"

int CSpriteBase2::init(CSpriteInit2* data)
{
  int r, g, b;
  r = data->r;
  g = data->g;
  b = data->b;
      
  mPause = data->pause;
  mNumFrames = data->numFrames;
  
  mAnim = new CSpriteFrame2[mNumFrames];
  
  SDL_Surface *temp;
  if((temp=SDL_LoadBMP(data->bmpFile))==NULL) {
  	printf("Loading %s failed...\n",data->bmpFile);
	return -1;
  }
  
  switch(data->align) {
  
  case CSPRITE2_VER:
	mW = temp->w;
	mH = temp->h/mNumFrames;
	break;
	  
  case CSPRITE2_HOR: 
  	mW = temp->w/mNumFrames;
	mH = temp->h;
	break;
	
  default:
	mW = temp->w;
	mH = temp->h/mNumFrames;
	break;
  }
  
  
  SDL_Rect srcr;
  srcr.x = 0;
  srcr.y = 0;  
  srcr.w = mW;
  srcr.h = mH;
  

  SDL_Surface *temp1;
  Uint32 rmask, gmask, bmask, amask;
  #if SDL_BYTEORDER == SDL_BIG_ENDIAN
    rmask = 0xff000000;
    gmask = 0x00ff0000;
    bmask = 0x0000ff00;
    amask = 0x000000ff;
  #else
    rmask = 0x000000ff;
    gmask = 0x0000ff00;
    bmask = 0x00ff0000;
    amask = 0xff000000;
  #endif
  temp1 = SDL_CreateRGBSurface(SDL_HWSURFACE|SDL_SRCCOLORKEY, mW, mH, 32,
                                   rmask, gmask, bmask, amask);
  if(temp1 == NULL) {
      fprintf(stderr, "CreateRGBSurface temp1 failed: %s\n", SDL_GetError());
      return -1;
  }

  
  for(int i=0; i<mNumFrames; i++){
    
    if(data->align == CSPRITE2_HOR){
    	srcr.x = i*mW;
	srcr.y = 0;
    }else{
    	srcr.x = 0;
	srcr.y = i*mH;
    }
    
    
    SDL_BlitSurface(temp,&srcr,temp1,NULL);

    if(r>=0 && g>=0 && b>=0)
      SDL_SetColorKey(temp1,SDL_SRCCOLORKEY,SDL_MapRGB(temp1->format,r,g,b));
    
    mAnim[i].image = SDL_DisplayFormat(temp1);
  }
  
  SDL_FreeSurface(temp1);
  SDL_FreeSurface(temp);
  return 0;
}
//-----------------------------------
